@@ -34,11 +34,12 @@ use crate::nixpacks::{
 };
 use anyhow::Result;
 use providers::{
-    clojure::ClojureProvider, crystal::CrystalProvider, csharp::CSharpProvider, dart::DartProvider,
-    deno::DenoProvider, elixir::ElixirProvider, fsharp::FSharpProvider, go::GolangProvider,
-    haskell::HaskellStackProvider, java::JavaProvider, node::NodeProvider, php::PhpProvider,
-    python::PythonProvider, ruby::RubyProvider, rust::RustProvider, staticfile::StaticfileProvider,
-    swift::SwiftProvider, zig::ZigProvider, Provider,
+    clojure::ClojureProvider, cobol::CobolProvider, crystal::CrystalProvider,
+    csharp::CSharpProvider, dart::DartProvider, deno::DenoProvider, elixir::ElixirProvider,
+    fsharp::FSharpProvider, go::GolangProvider, haskell::HaskellStackProvider, java::JavaProvider,
+    node::NodeProvider, php::PhpProvider, python::PythonProvider, ruby::RubyProvider,
+    rust::RustProvider, staticfile::StaticfileProvider, swift::SwiftProvider, zig::ZigProvider,
+    Provider,
 };
 
 mod chain;
@@ -66,6 +67,7 @@ pub fn get_providers() -> &'static [&'static dyn Provider] {
         &SwiftProvider {},
         &StaticfileProvider {},
         &ZigProvider {},
+        &CobolProvider {},
     ]
 }
 
